# Autodesk 3D Studio (.3ds)


---  


**Category**  
&nbsp;&nbsp; Import-Export  

**Menu**  
&nbsp;&nbsp; `File --> Import/Export --> Autodesk 3DS (.3ds)`  

**Version**  
&nbsp;&nbsp; 2.7.2  

**Authors**  
&nbsp;&nbsp; Bob Holcomb, Campbell Barton, Sebastian Schrand  

**Maintainer**  
&nbsp;&nbsp; Sebastian Sille (NRGSille)  

---  

The add-on has been moved from [Blender Add-ons repository](https://projects.blender.org/blender/blender-addons) and it will now be maintained here by [Sebastian Sille](https://projects.blender.org/NRGSille) and the Blender community.  
Bug reports will be tracked on the [Issue page](https://projects.blender.org/extensions/io_scene_3ds/issues) on this website. 
<br>

The add-on was part of the [Blender bundled add-ons](https://docs.blender.org/manual/en/4.1/addons). 
It is also available as an extension on the [Extensions platform](https://extensions.blender.org/add-ons/autodesk-3ds-format).  
<br>

The manual is no longer available on [Blender manual website](https://docs.blender.org/manual/en/dev/addons/import_export) instead it has been moved to this repository.  
-->[Autodesk 3DS IO manual](https://projects.blender.org/extensions/io_scene_3ds/wiki)<--  

Add on release notes are no longer available on [Blender developer docs](https://developer.blender.org/docs/release_notes) instead they can be found here:  
-->[Autodesk 3DS IO release notes](https://projects.blender.org/extensions/io_scene_3ds/src/branch/main/release_notes.md)<--


---
